@@ -1,7 +1,9 @@
 package App::lens;
 
-our $DATE = '2015-07-25'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-06-13'; # DATE
+our $DIST = 'App-lens'; # DIST
+our $VERSION = '0.020'; # VERSION
 
 1;
 # ABSTRACT: Transform colors in terminal output
@@ -18,15 +20,11 @@ App::lens - Transform colors in terminal output
 
 =head1 VERSION
 
-This document describes version 0.01 of App::lens (from Perl distribution App-lens), released on 2015-07-25.
+This document describes version 0.020 of App::lens (from Perl distribution App-lens), released on 2020-06-13.
 
 =head1 DESCRIPTION
 
-This distribution contains the script L<lens>.
-
-=head1 SEE ALSO
-
-L<lens>
+See included script L<lens>.
 
 =head1 HOMEPAGE
 
@@ -44,13 +42,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<lens>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
